@@ -31,13 +31,12 @@ public:
     ~EnvironmentPlainTextEdit();
 
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
 
-    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
-private Q_SLOTS:
+    void contextMenuEvent(QContextMenuEvent *event) override;
+private:
     void slotGeneralPaletteChanged();
 
-private:
     QColor mTextColor;
 };
 
